# EDN CONF #

This small library is built on https://pypi.org/project/edn-format/ 
It gives a trivial clojure interpreter (Only for math
operators). Morever, it is equiped with a namespaced keywords
resolution methods, which will find and import the specific Python
namespace. 
Finally, it gives some trivial reader macro for calling, and
partialing functions. 

## Installation ##

	pip install edn_conf
	
	


